@@ -366,6 +366,8 @@ strstrip(const char *input, const char *what)
 	char *str, *last;
 
 	str = xstrdup(&input[strspn(input, what)]);
+	if (!str)
+		return NULL;
 
 	last = str;
 
@@ -435,7 +437,7 @@ cmdline_as_str(void)
 	return procargs;
 #else
 	int fd = open("/proc/self/cmdline", O_RDONLY);
-	if (fd > 0) {
+	if (fd != -1) {
 		char buffer[1024] = {0};
 		int len = read(fd, buffer, sizeof(buffer) - 1);
 		close(fd);
